==> orchestra-base-tomcat-4.2.0.tar.gz: orchestra-base-tomcat-4.2.0/package/resources/db-schemas/history/org.hibernate.dialect.H2Dialect-drop.sql <==
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_PARENT_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_CH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_TH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_FH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_EXCEPTION_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_WAIT_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_CHILD_FK;
alter table BPEL_ACTIVITY_INST drop constraint SCOPE_INST_EVT_FK;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19F1C5FAB0;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D1982112BDD;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19614874B5;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19DE3B31AF;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19D4D0807A;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint SCOPE_DEF_FAULT_HANDLERS_FK;
alter table BPEL_FAULT_MSG_PART drop constraint BPEL_FAULT_MSG_PART_FK;
alter table COPY_FULL_IMPL drop constraint COPY_LST_FK;
alter table CORR_DEF_ drop constraint REC_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint IVK_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint RP_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint ON_EVT_CORR_FK;
alter table CORR_DEF_ drop constraint ON_MSG_CORR_FK;
alter table CS_INIT_FULL_IMPL drop constraint SCOPE_INST_CS_FK;
alter table ELSEIF_DEF_ drop constraint IF_ELSEIF_LST_FK;
alter table ELSEIF_DEF_ drop constraint FK4BC7A7A366DBBFD7;
alter table FRM_PRT_DEF_ drop constraint REC_FR_PT_LST_FK;
alter table FRM_PRT_DEF_ drop constraint IVK_FR_PT_LST_FK;
alter table FRM_PRT_DEF_ drop constraint ON_MSG_FRM_PRT_FK;
alter table FRM_PRT_DEF_ drop constraint ON_EVT_FRM_PRT_FK;
alter table FROM_TO_FULL drop constraint FROM_LST_FK;
alter table FROM_TO_FULL drop constraint TO_LST_FK;
alter table NOVA_CS_INST_PROP drop constraint CS_INST_PROP_FK;
alter table NOVA_VAR_MSG_PART2 drop constraint VAR_UPD_MSG_PART_FK;
alter table ON_ALRM_DEF_ drop constraint PK_DF_ON_AL_FK;
alter table ON_ALRM_DEF_ drop constraint FK5B79CBB3735C61C7;
alter table ON_ALRM_DEF_ drop constraint SCOPE_DEF_ALARMS_FK;
alter table ON_EVT_DEF_ drop constraint FKC013947699EA93C4;
alter table ON_EVT_DEF_ drop constraint SCOPE_DEF_EVTS_FK;
alter table ON_MSG_DEF_ drop constraint PK_DF_ON_MSG_FK;
alter table ON_MSG_DEF_ drop constraint FK4A3B4998A6853462;
alter table PART_LNK_DEF_ drop constraint SCOPE_DEF_PL_FK;
alter table PLNK_UPDATE_FULL_IMPL drop constraint SCOPE_INST_PLNK_FK;
alter table PROCESS_INST_STATE_UPDATE_ drop constraint PROCESS_INST_STATE_FK;
alter table SCOPE_STATE_UPDATE_ drop constraint SCOPE_INST_STATE_FK;
alter table SRC_FULL_IMPL drop constraint SRC_LST_FK;
alter table TGT_FULL_IMPL drop constraint TRGT_LST_FK;
alter table TO_PRT_DEF_ drop constraint RP_TO_PT_LST_FK;
alter table TO_PRT_DEF_ drop constraint IVK_TO_PT_LST_FK;
alter table TR_COND_UPD_ drop constraint FLOW_INST_TR_COND_FK;
alter table VAR_DEF_ drop constraint SCOPE_DEF_VAR_FK;
alter table VAR_DEF_CS_ drop constraint SCOPE_DEF_CS_FK;
alter table VAR_UPDATE_FULL_IMPL drop constraint SCOPE_INST_VAR_FK;
alter table WAITING_FULL_IMPL drop constraint PICK_WAIT_FK;
alter table linkList drop constraint FLOW_LINKS_FK;
alter table messageExchanges drop constraint SCOPE_DEF_M_E_FK;
alter table properties drop constraint CORR_ST_DEF_FK;
drop table BPEL_ACTIVITY_INST if exists;
drop table BPEL_BASE_ACTIVITY_DEF if exists;
drop table BPEL_FAULT_ if exists;
drop table BPEL_FAULT_MSG_PART if exists;
drop table COPY_FULL_IMPL if exists;
drop table CORR_DEF_ if exists;
drop table CS_INIT_FULL_IMPL if exists;
drop table ELSEIF_DEF_ if exists;
drop table FRM_PRT_DEF_ if exists;
drop table FROM_TO_FULL if exists;
drop table NOVA_CS_INST_PROP if exists;
drop table NOVA_NAMESPACE if exists;
drop table NOVA_VAR_MSG_PART2 if exists;
drop table ON_ALRM_DEF_ if exists;
drop table ON_EVT_DEF_ if exists;
drop table ON_MSG_DEF_ if exists;
drop table PART_LNK_DEF_ if exists;
drop table PLNK_UPDATE_FULL_IMPL if exists;
drop table PROCESS_INST_STATE_UPDATE_ if exists;
drop table SCOPE_STATE_UPDATE_ if exists;
drop table SRC_FULL_IMPL if exists;
drop table TGT_FULL_IMPL if exists;
drop table TO_PRT_DEF_ if exists;
drop table TR_COND_UPD_ if exists;
drop table VAR_DEF_ if exists;
drop table VAR_DEF_CS_ if exists;
drop table VAR_UPDATE_FULL_IMPL if exists;
drop table WAITING_FULL_IMPL if exists;
drop table linkList if exists;
drop table messageExchanges if exists;
drop table properties if exists;

==> orchestra-base-tomcat-4.4.1.tar.gz: orchestra-base-tomcat-4.4.1/package/resources/db-schemas/history/org.hibernate.dialect.H2Dialect-drop.sql <==
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_PARENT_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_CH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_TH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_FH_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_EXCEPTION_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_WAIT_FK;
alter table BPEL_ACTIVITY_INST drop constraint ACT_INST_CHILD_FK;
alter table BPEL_ACTIVITY_INST drop constraint SCOPE_INST_EVT_FK;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19F1C5FAB0;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D1982112BDD;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19614874B5;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19DE3B31AF;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint FK90444D19D4D0807A;
alter table BPEL_BASE_ACTIVITY_DEF drop constraint SCOPE_DEF_FAULT_HANDLERS_FK;
alter table COPY_FULL_IMPL drop constraint COPY_LST_FK;
alter table CORR_DEF_ drop constraint REC_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint IVK_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint RP_CR_DEF_LST_FK;
alter table CORR_DEF_ drop constraint ON_EVT_CORR_FK;
alter table CORR_DEF_ drop constraint ON_MSG_CORR_FK;
alter table CS_INIT_FULL_IMPL drop constraint SCOPE_INST_CS_FK;
alter table ELSEIF_DEF_ drop constraint IF_ELSEIF_LST_FK;
alter table ELSEIF_DEF_ drop constraint FK4BC7A7A366DBBFD7;
alter table FRM_PRT_DEF_ drop constraint REC_FR_PT_LST_FK;
alter table FRM_PRT_DEF_ drop constraint IVK_FR_PT_LST_FK;
alter table FRM_PRT_DEF_ drop constraint ON_MSG_FRM_PRT_FK;
alter table FRM_PRT_DEF_ drop constraint ON_EVT_FRM_PRT_FK;
alter table FROM_TO_FULL drop constraint FROM_LST_FK;
alter table FROM_TO_FULL drop constraint TO_LST_FK;
alter table NOVA_CS_INST_PROP drop constraint CS_INST_PROP_FK;
alter table ON_ALRM_DEF_ drop constraint PK_DF_ON_AL_FK;
alter table ON_ALRM_DEF_ drop constraint FK5B79CBB3735C61C7;
alter table ON_ALRM_DEF_ drop constraint SCOPE_DEF_ALARMS_FK;
alter table ON_EVT_DEF_ drop constraint FKC013947699EA93C4;
alter table ON_EVT_DEF_ drop constraint SCOPE_DEF_EVTS_FK;
alter table ON_MSG_DEF_ drop constraint PK_DF_ON_MSG_FK;
alter table ON_MSG_DEF_ drop constraint FK4A3B4998A6853462;
alter table PART_LNK_DEF_ drop constraint SCOPE_DEF_PL_FK;
alter table PLNK_UPDATE_FULL_IMPL drop constraint SCOPE_INST_PLNK_FK;
alter table PROCESS_INST_STATE_UPDATE_ drop constraint PROCESS_INST_STATE_FK;
alter table SCOPE_STATE_UPDATE_ drop constraint SCOPE_INST_STATE_FK;
alter table SRC_FULL_IMPL drop constraint SRC_LST_FK;
alter table TGT_FULL_IMPL drop constraint TRGT_LST_FK;
alter table TO_PRT_DEF_ drop constraint RP_TO_PT_LST_FK;
alter table TO_PRT_DEF_ drop constraint IVK_TO_PT_LST_FK;
alter table TR_COND_UPD_ drop constraint FLOW_INST_TR_COND_FK;
alter table VAR_DEF_ drop constraint SCOPE_DEF_VAR_FK;
alter table VAR_DEF_CS_ drop constraint SCOPE_DEF_CS_FK;
alter table VAR_UPDATE_FULL_IMPL drop constraint SCOPE_INST_VAR_FK;
alter table WAITING_FULL_IMPL drop constraint PICK_WAIT_FK;
alter table linkList drop constraint FLOW_LINKS_FK;
alter table messageExchanges drop constraint SCOPE_DEF_M_E_FK;
alter table properties drop constraint CORR_ST_DEF_FK;
drop table BPEL_ACTIVITY_INST if exists;
drop table BPEL_BASE_ACTIVITY_DEF if exists;
drop table BPEL_FAULT_ if exists;
drop table BPEL_REC if exists;
drop table COPY_FULL_IMPL if exists;
drop table CORR_DEF_ if exists;
drop table CS_INIT_FULL_IMPL if exists;
drop table ELSEIF_DEF_ if exists;
drop table FRM_PRT_DEF_ if exists;
drop table FROM_TO_FULL if exists;
drop table NOVA_CS_INST_PROP if exists;
drop table NOVA_NAMESPACE if exists;
drop table ON_ALRM_DEF_ if exists;
drop table ON_EVT_DEF_ if exists;
drop table ON_MSG_DEF_ if exists;
drop table PART_LNK_DEF_ if exists;
drop table PLNK_UPDATE_FULL_IMPL if exists;
drop table PROCESS_INST_STATE_UPDATE_ if exists;
drop table SCOPE_STATE_UPDATE_ if exists;
drop table SRC_FULL_IMPL if exists;
drop table TGT_FULL_IMPL if exists;
drop table TO_PRT_DEF_ if exists;
drop table TR_COND_UPD_ if exists;
drop table VAR_DEF_ if exists;
drop table VAR_DEF_CS_ if exists;
drop table VAR_UPDATE_FULL_IMPL if exists;
drop table WAITING_FULL_IMPL if exists;
drop table linkList if exists;
drop table messageExchanges if exists;
drop table properties if exists;
drop table orchestra_sequences if exists;
